@@ -30,6 +30,7 @@
 #include <QFileDialog>
 #include <QBuffer>
 #include <QRegularExpression>
+#include <QRegularExpressionMatch>
 
 #include <KLocalizedString>
 #include <KSharedConfig>
@@ -44,12 +45,11 @@
 ExportManager::ExportManager(QObject *parent) :
     QObject(parent),
     mSavePixmap(QPixmap()),
-    mLastSavePath(QUrl()),
     mTempFile(QUrl()),
     mTempDir(nullptr)
 {
     connect(this, &ExportManager::imageSaved, [this](const QUrl savedAt) {
-        mLastSavePath = savedAt;
+        SpectacleConfig::instance()->setLastSaveFile(savedAt);
     });
 }
 
@@ -104,15 +104,16 @@ void ExportManager::setPixmap(const QPixmap &pixmap)
     }
 }
 
+void ExportManager::updatePixmapTimestamp()
+{
+	mPixmapTimestamp = QDateTime::currentDateTime();
+}
+
 // native file save helpers
 
-QString ExportManager::saveLocation() const
+QString ExportManager::defaultSaveLocation() const
 {
-    KSharedConfigPtr config = KSharedConfig::openConfig(QStringLiteral("spectaclerc"));
-    KConfigGroup generalConfig = KConfigGroup(config, "General");
-
-    QString savePath = generalConfig.readPathEntry(
-                "default-save-location", QStandardPaths::writableLocation(QStandardPaths::PicturesLocation));
+    QString savePath = SpectacleConfig::instance()->defaultSaveLocation();
     if (savePath.isEmpty() || savePath.isNull()) {
         savePath = QDir::homePath();
     }
@@ -121,28 +122,15 @@ QString ExportManager::saveLocation() const
     QDir savePathDir(savePath);
     if (!(savePathDir.exists())) {
         savePathDir.mkpath(QStringLiteral("."));
-        generalConfig.writePathEntry("last-saved-to", savePath);
+        SpectacleConfig::instance()->setDefaultSaveLocation(savePath);
     }
 
     return savePath;
 }
 
-QUrl ExportManager::lastSavePath() const
-{
-    return isFileExists(mLastSavePath) ? mLastSavePath : QUrl();
-}
-
-void ExportManager::setSaveLocation(const QString &savePath)
-{
-    KSharedConfigPtr config = KSharedConfig::openConfig(QStringLiteral("spectaclerc"));
-    KConfigGroup generalConfig = KConfigGroup(config, "General");
-
-    generalConfig.writePathEntry("last-saved-to", savePath);
-}
-
 QUrl ExportManager::getAutosaveFilename()
 {
-    const QString baseDir = saveLocation();
+    const QString baseDir = defaultSaveLocation();
     const QDir baseDirPath(baseDir);
     const QString filename = makeAutosaveFilename();
     const QString fullpath = autoIncrementFilename(baseDirPath.filePath(filename),
@@ -170,12 +158,9 @@ QString ExportManager::truncatedFilename(QString const &filename)
 
 QString ExportManager::makeAutosaveFilename()
 {
-    KSharedConfigPtr config = KSharedConfig::openConfig(QStringLiteral("spectaclerc"));
-    KConfigGroup generalConfig = KConfigGroup(config, "General");
-
-    const QDateTime timestamp = QDateTime::currentDateTime();
-    QString baseName = generalConfig.readEntry("save-filename-format", "Screenshot_%Y%M%D_%H%m%S");
-
+    const QDateTime timestamp = mPixmapTimestamp;
+    QString baseName = SpectacleConfig::instance()->autoSaveFilenameFormat();
+    const QString baseDir = defaultSaveLocation();
     QString title;
 
     if (mGrabMode == ImageGrabber::GrabMode::ActiveWindow ||
@@ -198,6 +183,51 @@ QString ExportManager::makeAutosaveFilename()
                              .replace(QLatin1String("%m"), timestamp.toString(QStringLiteral("mm")))
                              .replace(QLatin1String("%S"), timestamp.toString(QStringLiteral("ss")))
                              .replace(QLatin1String("%T"), title);
+                             
+    // check if basename includes %[N]d token for sequential file numbering
+    QRegularExpression paddingRE;
+    paddingRE.setPattern(QLatin1String("%(\\d*)d"));
+    QRegularExpressionMatch paddingMatch;
+                             
+    if (result.indexOf(paddingRE, 0, &paddingMatch) > -1) {
+        int highestFileNumber = 0;
+
+        // determine padding value
+        int paddedLength = 1;
+        if (!paddingMatch.captured(1).isEmpty()) {
+            paddedLength = paddingMatch.captured(1).toInt();
+        }
+
+        // seach save directory for files
+        QDir dir(baseDir);
+        const QStringList fileNames = dir.entryList(QDir::Files, QDir::Name);
+        
+        // if there are files in the directory...
+        if (fileNames.length() > 0) { 
+            QString resultCopy = result;
+            QRegularExpression fileNumberRE;
+            const QString replacement = QString::fromLatin1("(\\d{").append(QString::number(paddedLength)).append(QString::fromLatin1(",})"));
+            const QString fullNameMatch = QStringLiteral("^").append(resultCopy.replace(paddingMatch.captured(),replacement)).append(QStringLiteral("\\..*$"));
+            fileNumberRE.setPattern(fullNameMatch);
+
+            // ... check the file names for string matching token with padding specified in result
+            const QStringList filteredFiles = fileNames.filter(fileNumberRE);
+
+            // if there are files in the direcory that look like the file name with sequential numbering
+            if (filteredFiles.length() > 0) {
+                // loop through filtered file names looking for highest number
+                for (const QString &filteredFile: filteredFiles) {
+                    int currentFileNumber = fileNumberRE.match(filteredFile).captured(1).toInt();
+                    if (currentFileNumber > highestFileNumber) {
+                        highestFileNumber = currentFileNumber;
+                    }
+                }
+            }
+        }
+        // replace placeholder with next number padded
+        const QString nextFileNumberPadded = QString::number(highestFileNumber + 1).rightJustified(paddedLength, QLatin1Char('0'));
+        result = result.replace(paddingMatch.captured(), nextFileNumberPadded);
+    }
 
     // Remove leading and trailing '/'
     while (result.startsWith(QLatin1Char('/'))) {
@@ -208,7 +238,7 @@ QString ExportManager::makeAutosaveFilename()
     }
 
     if (result.isEmpty()) {
-        result = QStringLiteral("Screenshot");
+        result = SpectacleConfig::instance()->defaultFilename();
     }
     return truncatedFilename(result);
 }
@@ -292,7 +322,7 @@ bool ExportManager::remoteSave(const QUrl &url, const QString &mimetype)
 
     if (listJob->error() != KJob::NoError) {
         // Create remote save directory
-        KIO::MkpathJob *mkpathJob = KIO::mkpath(dirPath, QUrl(saveLocation()));
+        KIO::MkpathJob *mkpathJob = KIO::mkpath(dirPath, QUrl(defaultSaveLocation()));
         mkpathJob->exec();
 
         if (mkpathJob->error() != KJob::NoError) {
@@ -405,7 +435,7 @@ void ExportManager::doSave(const QUrl &url, bool notify)
     if (save(savePath)) {
         QDir dir(savePath.path());
         dir.cdUp();
-        setSaveLocation(dir.absolutePath());
+        SpectacleConfig::instance()->setLastSaveFile(savePath);
 
         emit imageSaved(savePath);
         if (notify) {
@@ -425,14 +455,16 @@ bool ExportManager::doSaveAs(QWidget *parentWindow, bool notify)
     }
 
     // construct the file name
+    const QString filenameExtension = SpectacleConfig::instance()->saveImageFormat();
+    const QString mimetype = QMimeDatabase().mimeTypeForFile(QStringLiteral("~/fakefile.") + filenameExtension, QMimeDatabase::MatchExtension).name();
     QFileDialog dialog(parentWindow);
     dialog.setAcceptMode(QFileDialog::AcceptSave);
     dialog.setFileMode(QFileDialog::AnyFile);
     dialog.setDirectoryUrl(config->lastSaveAsLocation());
-    dialog.selectFile(makeAutosaveFilename() + QStringLiteral(".png"));
-    dialog.setDefaultSuffix(QStringLiteral(".png"));
+    dialog.selectFile(makeAutosaveFilename() + QStringLiteral(".") + filenameExtension);
+    dialog.setDefaultSuffix(QStringLiteral(".") + filenameExtension);
     dialog.setMimeTypeFilters(supportedFilters);
-    dialog.selectMimeTypeFilter(QStringLiteral("image/png"));
+    dialog.selectMimeTypeFilter(mimetype);
 
     // launch the dialog
     if (dialog.exec() == QFileDialog::Accepted) {
@@ -440,7 +472,7 @@ bool ExportManager::doSaveAs(QWidget *parentWindow, bool notify)
         if (saveUrl.isValid()) {
             if (save(saveUrl)) {
                 emit imageSaved(saveUrl);
-                config->setLastSaveAsLocation(saveUrl.adjusted(QUrl::RemoveFilename));
+                config->setLastSaveAsFile(saveUrl);
 
                 if (notify) {
                     emit forceNotify(saveUrl);
