@@ -42,6 +42,12 @@ class SpectacleConfig : public QObject
 
     static SpectacleConfig* instance();
 
+    QString defaultFilename() const;
+    QString defaultTimestampTemplate() const;
+    
+    QUrl lastSaveAsLocation() const;
+    QUrl lastSaveLocation() const;
+    
     private:
 
     explicit SpectacleConfig(QObject *parent = nullptr);
@@ -52,10 +58,13 @@ class SpectacleConfig : public QObject
 
     // everything else
 
-    public slots:
+    public Q_SLOTS:
 
-    QUrl lastSaveAsLocation() const;
-    void setLastSaveAsLocation(const QUrl &location);
+    QUrl lastSaveAsFile() const;
+    void setLastSaveAsFile(const QUrl &location);
+
+    QUrl lastSaveFile() const;
+    void setLastSaveFile(const QUrl &location);
 
     QRect cropRegion() const;
     void setCropRegion(const QRect &region);
@@ -96,8 +105,8 @@ class SpectacleConfig : public QObject
     QString autoSaveFilenameFormat() const;
     void setAutoSaveFilenameFormat(const QString &format);
 
-    QString autoSaveLocation() const;
-    void setAutoSaveLocation(const QString &location);
+    QString defaultSaveLocation() const;
+    void setDefaultSaveLocation(const QString &location);
 
     bool copySaveLocationToClipboard() const;
     void setCopySaveLocationToClipboard(bool enabled);
